==> koffice2_1.9.93.orig.tar.gz: koffice-1.9.93/shapes/pathshapes/rectangle/RectangleShapeConfigCommand.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "RectangleShapeConfigCommand.h"
#include "KoRectangleShape.h"
#include <klocale.h>

RectangleShapeConfigCommand::RectangleShapeConfigCommand( KoRectangleShape * rectangle, double cornerRadiusX, double cornerRadiusY, QUndoCommand *parent )
    : QUndoCommand( parent )
    , m_rectangle(rectangle)
    , m_newCornerRadiusX(cornerRadiusX)
    , m_newCornerRadiusY(cornerRadiusY)
{
    Q_ASSERT(m_rectangle);

    setText( i18n("Change rectangle") );

    m_oldCornerRadiusX = m_rectangle->cornerRadiusX();
    m_oldCornerRadiusY = m_rectangle->cornerRadiusY();
}

void RectangleShapeConfigCommand::redo()
{
    QUndoCommand::redo();

    m_rectangle->repaint();

    if( m_oldCornerRadiusX != m_newCornerRadiusX )
        m_rectangle->setCornerRadiusX( m_newCornerRadiusX );
    if( m_oldCornerRadiusY != m_newCornerRadiusY )
        m_rectangle->setCornerRadiusY( m_newCornerRadiusY );

    m_rectangle->repaint();
}

void RectangleShapeConfigCommand::undo()
{
    QUndoCommand::undo();

    m_rectangle->repaint();

    if( m_oldCornerRadiusX != m_newCornerRadiusX )
        m_rectangle->setCornerRadiusX( m_oldCornerRadiusX );
    if( m_oldCornerRadiusY != m_newCornerRadiusY )
        m_rectangle->setCornerRadiusY( m_oldCornerRadiusY );

    m_rectangle->repaint();
}

==> koffice2_1.9.95.orig.tar.gz: koffice-1.9.95/shapes/pathshapes/rectangle/RectangleShapeConfigCommand.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "RectangleShapeConfigCommand.h"
#include "KoRectangleShape.h"
#include <klocale.h>

RectangleShapeConfigCommand::RectangleShapeConfigCommand( KoRectangleShape * rectangle, double cornerRadiusX, double cornerRadiusY, QUndoCommand *parent )
    : QUndoCommand( parent )
    , m_rectangle(rectangle)
    , m_newCornerRadiusX(cornerRadiusX)
    , m_newCornerRadiusY(cornerRadiusY)
{
    Q_ASSERT(m_rectangle);

    setText( i18n("Change rectangle") );

    m_oldCornerRadiusX = m_rectangle->cornerRadiusX();
    m_oldCornerRadiusY = m_rectangle->cornerRadiusY();
}

void RectangleShapeConfigCommand::redo()
{
    QUndoCommand::redo();

    m_rectangle->update();

    if( m_oldCornerRadiusX != m_newCornerRadiusX )
        m_rectangle->setCornerRadiusX( m_newCornerRadiusX );
    if( m_oldCornerRadiusY != m_newCornerRadiusY )
        m_rectangle->setCornerRadiusY( m_newCornerRadiusY );

    m_rectangle->update();
}

void RectangleShapeConfigCommand::undo()
{
    QUndoCommand::undo();

    m_rectangle->update();

    if( m_oldCornerRadiusX != m_newCornerRadiusX )
        m_rectangle->setCornerRadiusX( m_oldCornerRadiusX );
    if( m_oldCornerRadiusY != m_newCornerRadiusY )
        m_rectangle->setCornerRadiusY( m_oldCornerRadiusY );

    m_rectangle->update();
}
